<?php

namespace Litecms\Transactioninsert\Http\Controllers;

use App\Http\Controllers\ResourceController as BaseController;
use Form;
use Litecms\Transactioninsert\Http\Requests\TransactioninsertRequest;
use Litecms\Transactioninsert\Interfaces\TransactioninsertRepositoryInterface;
use Litecms\Transactioninsert\Models\Transactioninsert;

/**
 * Resource controller class for transactioninsert.
 */
class TransactioninsertResourceController extends BaseController
{

    /**
     * Initialize transactioninsert resource controller.
     *
     * @param type TransactioninsertRepositoryInterface $transactioninsert
     *
     * @return null
     */
    public function __construct(TransactioninsertRepositoryInterface $transactioninsert)
    {
        parent::__construct();
        $this->repository = $transactioninsert;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Litecms\Transactioninsert\Repositories\Criteria\TransactioninsertResourceCriteria::class);
    }

    /**
     * Display a list of transactioninsert.
     *
     * @return Response
     */
    public function index(TransactioninsertRequest $request)
    {
        $view = $this->response->theme->listView();

        if ($this->response->typeIs('json')) {
            $function = camel_case('get-' . $view);
            return $this->repository
                ->setPresenter(\Litecms\Transactioninsert\Repositories\Presenter\TransactioninsertPresenter::class)
                ->$function();
        }

        $transactioninserts = $this->repository->paginate();

        return $this->response->title(trans('transactioninsert::transactioninsert.names'))
            ->view('transactioninsert::transactioninsert.index', true)
            ->data(compact('transactioninserts'))
            ->output();
    }

    /**
     * Display transactioninsert.
     *
     * @param Request $request
     * @param Model   $transactioninsert
     *
     * @return Response
     */
    public function show(TransactioninsertRequest $request, Transactioninsert $transactioninsert)
    {

        if ($transactioninsert->exists) {
            $view = 'transactioninsert::transactioninsert.show';
        } else {
            $view = 'transactioninsert::transactioninsert.new';
        }

        return $this->response->title(trans('app.view') . ' ' . trans('transactioninsert::transactioninsert.name'))
            ->data(compact('transactioninsert'))
            ->view($view, true)
            ->output();
    }

    /**
     * Show the form for creating a new transactioninsert.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(TransactioninsertRequest $request)
    {

        $transactioninsert = $this->repository->newInstance([]);
        return $this->response->title(trans('app.new') . ' ' . trans('transactioninsert::transactioninsert.name')) 
            ->view('transactioninsert::transactioninsert.create', true) 
            ->data(compact('transactioninsert'))
            ->output();
    }

    /**
     * Create new transactioninsert.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(TransactioninsertRequest $request)
    {
        try {
            $attributes              = $request->all();
            $attributes['user_id']   = user_id();
            $attributes['user_type'] = user_type();
            $transactioninsert                 = $this->repository->create($attributes);

            return $this->response->message(trans('messages.success.created', ['Module' => trans('transactioninsert::transactioninsert.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('transactioninsert/transactioninsert/' . $transactioninsert->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('/transactioninsert/transactioninsert'))
                ->redirect();
        }

    }

    /**
     * Show transactioninsert for editing.
     *
     * @param Request $request
     * @param Model   $transactioninsert
     *
     * @return Response
     */
    public function edit(TransactioninsertRequest $request, Transactioninsert $transactioninsert)
    {
        return $this->response->title(trans('app.edit') . ' ' . trans('transactioninsert::transactioninsert.name'))
            ->view('transactioninsert::transactioninsert.edit', true)
            ->data(compact('transactioninsert'))
            ->output();
    }

    /**
     * Update the transactioninsert.
     *
     * @param Request $request
     * @param Model   $transactioninsert
     *
     * @return Response
     */
    public function update(TransactioninsertRequest $request, Transactioninsert $transactioninsert)
    {
        try {
            $attributes = $request->all();

            $transactioninsert->update($attributes);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('transactioninsert::transactioninsert.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('transactioninsert/transactioninsert/' . $transactioninsert->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('transactioninsert/transactioninsert/' . $transactioninsert->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove the transactioninsert.
     *
     * @param Model   $transactioninsert
     *
     * @return Response
     */
    public function destroy(TransactioninsertRequest $request, Transactioninsert $transactioninsert)
    {
        try {

            $transactioninsert->delete();
            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('transactioninsert::transactioninsert.name')]))
                ->code(202)
                ->status('success')
                ->url(guard_url('transactioninsert/transactioninsert/0'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('transactioninsert/transactioninsert/' . $transactioninsert->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove multiple transactioninsert.
     *
     * @param Model   $transactioninsert
     *
     * @return Response
     */
    public function delete(TransactioninsertRequest $request, $type)
    {
        try {
            $ids = hashids_decode($request->input('ids'));

            if ($type == 'purge') {
                $this->repository->purge($ids);
            } else {
                $this->repository->delete($ids);
            }

            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('transactioninsert::transactioninsert.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('transactioninsert/transactioninsert'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/transactioninsert/transactioninsert'))
                ->redirect();
        }

    }

    /**
     * Restore deleted transactioninserts.
     *
     * @param Model   $transactioninsert
     *
     * @return Response
     */
    public function restore(TransactioninsertRequest $request)
    {
        try {
            $ids = hashids_decode($request->input('ids'));
            $this->repository->restore($ids);

            return $this->response->message(trans('messages.success.restore', ['Module' => trans('transactioninsert::transactioninsert.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('/transactioninsert/transactioninsert'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/transactioninsert/transactioninsert/'))
                ->redirect();
        }

    }

}
